@@ -12,9 +12,9 @@ def setup_module():
     global motu
     motu = 'http://nrt.cmems-du.eu/motu-web/Motu'
     global user
-    user = os.getenv('CMEMS_USR')
+    user = os.environ['CMEMS_USR']
     global password
-    password = os.environ.get('CMEMS_PWD')
+    password = os.environ['CMEMS_PWD']
 
 
 def test_fail_download_wrong_url():
